ImageTranslatorFGR - Feature Generation&Regression
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. currentmodule:: aydin.it.fgr

.. autoclass:: ImageTranslatorFGR
    :members:
    :inherited-members:
